==> xfburn_0.2.0.orig.tar.gz: xfburn-0.2.0/xfburn/xfburn-data-disc-usage.h <==
/* $Id: xfburn-data-disc-usage.h 22714 2006-08-11 16:02:53Z pollux $ */
/*
 * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFBURN_DATA_DISC_USAGE_H__
#define __XFBURN_DATA_DISC_USAGE_H__

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define XFBURN_TYPE_DATA_DISC_USAGE            (xfburn_data_disc_usage_get_type ())
#define XFBURN_DATA_DISC_USAGE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), XFBURN_TYPE_DATA_DISC_USAGE, XfburnDataDiscUsage))
#define XFBURN_DATA_DISC_USAGE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), XFBURN_TYPE_DATA_DISC_USAGE, XfburnDataDiscUsageClass))
#define XFBURN_IS_DATA_DISC_USAGE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XFBURN_TYPE_DATA_DISC_USAGE))
#define XFBURN_IS_DATA_DISC_USAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XFBURN_TYPE_DATA_DISC_USAGE))
#define XFBURN_DATA_DISC_USAGE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), XFBURN_TYPE_DATA_DISC_USAGE, XfburnDataDiscUsageClass))

typedef struct
{
  GtkVBox hbox;

  GtkWidget *progress_bar;
  GtkWidget *combo;
  GtkWidget *button;

  gdouble size;
} XfburnDataDiscUsage;

typedef struct
{
  GtkHBoxClass parent_class;
  
  void (*begin_burn) (XfburnDataDiscUsage *du);
} XfburnDataDiscUsageClass;

GtkType xfburn_data_disc_usage_get_type (void);
GtkWidget *xfburn_data_disc_usage_new (void);

gdouble xfburn_data_disc_usage_get_size (XfburnDataDiscUsage *);
void xfburn_data_disc_usage_set_size (XfburnDataDiscUsage *, gdouble);
void xfburn_data_disc_usage_add_size (XfburnDataDiscUsage *, gdouble);
void xfburn_data_disc_usage_sub_size (XfburnDataDiscUsage *, gdouble);

G_END_DECLS

#endif

==> xfburn_0.3.2.orig.tar.gz: xfburn-0.3.2/xfburn/xfburn-data-disc-usage.h <==
/* $Id: xfburn-data-disc-usage.h 5095 2008-07-15 15:05:01Z squisher $ */
/*
 * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __XFBURN_DATA_DISC_USAGE_H__
#define __XFBURN_DATA_DISC_USAGE_H__

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define XFBURN_TYPE_DATA_DISC_USAGE            (xfburn_data_disc_usage_get_type ())
#define XFBURN_DATA_DISC_USAGE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), XFBURN_TYPE_DATA_DISC_USAGE, XfburnDataDiscUsage))
#define XFBURN_DATA_DISC_USAGE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), XFBURN_TYPE_DATA_DISC_USAGE, XfburnDataDiscUsageClass))
#define XFBURN_IS_DATA_DISC_USAGE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), XFBURN_TYPE_DATA_DISC_USAGE))
#define XFBURN_IS_DATA_DISC_USAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), XFBURN_TYPE_DATA_DISC_USAGE))
#define XFBURN_DATA_DISC_USAGE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), XFBURN_TYPE_DATA_DISC_USAGE, XfburnDataDiscUsageClass))

typedef struct
{
  GtkVBox hbox;

  GtkWidget *progress_bar;
  GtkWidget *combo;
  GtkWidget *button;

  gdouble size;
} XfburnDataDiscUsage;

typedef struct
{
  GtkHBoxClass parent_class;
  
  void (*begin_burn) (XfburnDataDiscUsage *du);
} XfburnDataDiscUsageClass;

typedef enum
{
  CD_DISC,
  DVD_DISC,
} XfburnDataDiscType;

GtkType xfburn_data_disc_usage_get_type (void);
GtkWidget *xfburn_data_disc_usage_new (void);

gdouble xfburn_data_disc_usage_get_size (XfburnDataDiscUsage *);
void xfburn_data_disc_usage_set_size (XfburnDataDiscUsage *, gdouble);
void xfburn_data_disc_usage_add_size (XfburnDataDiscUsage *, gdouble);
void xfburn_data_disc_usage_sub_size (XfburnDataDiscUsage *, gdouble);

XfburnDataDiscType xfburn_data_disc_usage_get_disc_type (XfburnDataDiscUsage *);

G_END_DECLS

#endif
